@@ -34,6 +34,7 @@ from girder import logger
 from girder.api import access
 from girder.api.describe import Description, autoDescribeRoute, describeRoute
 from girder.api.rest import Resource
+from girder.constants import TokenScope
 from girder.exceptions import RestException
 from girder.models.file import File
 from girder.models.item import Item
@@ -241,7 +242,7 @@ class LargeImageResource(Resource):
     @describeRoute(
         Description('Clear tile source caches to release resources and file handles.')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def cacheClear(self, params):
         before = cache_util.cachesInfo()
         cache_util.cachesClear()
@@ -256,14 +257,14 @@ class LargeImageResource(Resource):
     @describeRoute(
         Description('Get information on caches.')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_READ)
     def cacheInfo(self, params):
         return cache_util.cachesInfo()
 
     @describeRoute(
         Description('Get public settings for large image display.')
     )
-    @access.public
+    @access.public(scope=TokenScope.DATA_READ)
     def getPublicSettings(self, params):
         keys = [getattr(constants.PluginSettings, key)
                 for key in dir(constants.PluginSettings)
@@ -278,7 +279,7 @@ class LargeImageResource(Resource):
                'specifications typically include width, height, encoding, and '
                'encoding options.', required=False)
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_READ)
     def countThumbnails(self, params):
         return self._countCachedImages(params.get('spec'))
 
@@ -289,7 +290,7 @@ class LargeImageResource(Resource):
                'specified key', required=False)
         .notes('The imageKey can also be "tileFrames".')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_READ)
     def countAssociatedImages(self, params):
         return self._countCachedImages(
             None, associatedImages=True, imageKey=params.get('imageKey'))
@@ -337,7 +338,7 @@ class LargeImageResource(Resource):
                'making thumbnails.  0 or unspecified to base this on the '
                'number of reported cpus.', required=False, dataType='int')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def createThumbnails(self, params):
         self.requireParams(['spec'], params)
         try:
@@ -375,7 +376,7 @@ class LargeImageResource(Resource):
                'specifications typically include width, height, encoding, and '
                'encoding options.', required=False)
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def deleteThumbnails(self, params):
         return self._deleteCachedImages(params.get('spec'))
 
@@ -384,7 +385,7 @@ class LargeImageResource(Resource):
         .param('imageKey', 'If specific, only include images with the '
                'specified key', required=False)
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def deleteAssociatedImages(self, params):
         return self._deleteCachedImages(
             None, associatedImages=True, imageKey=params.get('imageKey'))
@@ -424,7 +425,7 @@ class LargeImageResource(Resource):
                'cancelled.  The return value is the number of items that were '
                'adjusted.')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def deleteIncompleteTiles(self, params):
         result = {'removed': 0}
         while True:
@@ -447,10 +448,10 @@ class LargeImageResource(Resource):
     @describeRoute(
         Description('List all Girder tile sources with associated extensions, '
                     'mime types, and versions.  Lower values indicate a '
-                    'higher priority for an extension of mime type with that '
+                    'higher priority for an extension or mime type with that '
                     'source.')
     )
-    @access.public
+    @access.public(scope=TokenScope.DATA_READ)
     def listSources(self, params):
         results = {}
         for key, source in girder_tilesource.AvailableGirderTileSources.items():
@@ -472,7 +473,7 @@ class LargeImageResource(Resource):
     @describeRoute(
         Description('Count the number of cached histograms for large_image items.')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_READ)
     def countHistograms(self, params):
         query = {
             'isLargeImageData': True,
@@ -485,7 +486,7 @@ class LargeImageResource(Resource):
     @describeRoute(
         Description('Delete cached histograms from large_image items.')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def deleteHistograms(self, params):
         query = {
             'isLargeImageData': True,
@@ -560,17 +561,17 @@ class LargeImageResource(Resource):
         .param('config', 'The contents of config file to validate.',
                paramType='body')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def configValidate(self, config):
         config = config.read().decode('utf8')
         return self._configValidate(config)
 
-    @autoDescribeRoute(
+    @autoDescribeRoute(  # noqa
         Description('Reformat a Girder config file')
         .param('config', 'The contents of config file to format.',
                paramType='body')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.DATA_WRITE)
     def configFormat(self, config):  # noqa
         config = config.read().decode('utf8')
         if len(self._configValidate(config)):
@@ -626,7 +627,7 @@ class LargeImageResource(Resource):
         .param('config', 'The new contents of config file.',
                paramType='body')
     )
-    @access.admin
+    @access.admin(scope=TokenScope.USER_AUTH)
     def configReplace(self, config, restart):
         config = config.read().decode('utf8')
         if len(self._configValidate(config)):
